==> libopenshot-audio-docs-0.3.0-1-aarch64.pkg.tar.xz: usr/share/doc/OpenShotAudio/API/classjuce_1_1AudioDeviceManager.js <==
var classjuce_1_1AudioDeviceManager =
[
    [ "AudioDeviceSetup", "structjuce_1_1AudioDeviceManager_1_1AudioDeviceSetup.html", "structjuce_1_1AudioDeviceManager_1_1AudioDeviceSetup" ],
    [ "LevelMeter", "structjuce_1_1AudioDeviceManager_1_1LevelMeter.html", null ],
    [ "AudioDeviceManager", "classjuce_1_1AudioDeviceManager.html#a0f94252c05cdcfb54bbe5268b8c899c1", null ],
    [ "~AudioDeviceManager", "classjuce_1_1AudioDeviceManager.html#aa75a7b8cdfe4140f2b5f2c29079ad597", null ],
    [ "addAudioCallback", "classjuce_1_1AudioDeviceManager.html#ab8142650e2dc99996da8e8680861ab2e", null ],
    [ "addAudioDeviceType", "classjuce_1_1AudioDeviceManager.html#af34a975de197da7f381c66b649ea80b7", null ],
    [ "addMidiInputCallback", "classjuce_1_1AudioDeviceManager.html#a98d86b9fbff5d7d07554d018c9e57f80", null ],
    [ "addMidiInputDeviceCallback", "classjuce_1_1AudioDeviceManager.html#a99e95f950308e4819eaef5bb00950ebd", null ],
    [ "closeAudioDevice", "classjuce_1_1AudioDeviceManager.html#af953ec126738f7cb6a32a9b2dc1a3d71", null ],
    [ "createAudioDeviceTypes", "classjuce_1_1AudioDeviceManager.html#a4e7b2c8576293258d578aa9a047ad1b3", null ],
    [ "createStateXml", "classjuce_1_1AudioDeviceManager.html#afa4b3140e09746cddfa28b230aeb2687", null ],
    [ "getAudioCallbackLock", "classjuce_1_1AudioDeviceManager.html#ab2432e30713bfb4c70937e740fda3674", null ],
    [ "getAudioDeviceSetup", "classjuce_1_1AudioDeviceManager.html#a259eff30308a989151915257f0b36c19", null ],
    [ "getAudioDeviceSetup", "classjuce_1_1AudioDeviceManager.html#a8e38b3ad92023fc1ab397bd1ca92ff85", null ],
    [ "getAvailableDeviceTypes", "classjuce_1_1AudioDeviceManager.html#aa792795a2b934872135d7c4038bca414", null ],
    [ "getCpuUsage", "classjuce_1_1AudioDeviceManager.html#a2fc200595e625e07ce7ef0f8fe046c85", null ],
    [ "getCurrentAudioDevice", "classjuce_1_1AudioDeviceManager.html#a46c369de913882cca55a1c1f80a0a818", null ],
    [ "getCurrentAudioDeviceType", "classjuce_1_1AudioDeviceManager.html#a4dc6b28ff963bbacc26d8f7279ae2ac3", null ],
    [ "getCurrentDeviceTypeObject", "classjuce_1_1AudioDeviceManager.html#a30b3777cba7f46b18f89afb1089054a9", null ],
    [ "getDefaultMidiOutput", "classjuce_1_1AudioDeviceManager.html#a081e904378810fbf6a3c11bf9a7d0231", null ],
    [ "getDefaultMidiOutputIdentifier", "classjuce_1_1AudioDeviceManager.html#a2918c2cf418155c37bf9924820e700c9", null ],
    [ "getDefaultMidiOutputName", "classjuce_1_1AudioDeviceManager.html#a0462c364efccff0c917a1bd8cef6a116", null ],
    [ "getInputLevelGetter", "classjuce_1_1AudioDeviceManager.html#a0e2b2e556d1d1b64fdf9ce5991eb2713", null ],
    [ "getMidiCallbackLock", "classjuce_1_1AudioDeviceManager.html#a0ee22305ac3a05454e335311f50d9ebf", null ],
    [ "getOutputLevelGetter", "classjuce_1_1AudioDeviceManager.html#a417f8b4d46c8ada26493734532399977", null ],
    [ "getXRunCount", "classjuce_1_1AudioDeviceManager.html#a7e4900c55e080cbbdf646e3e31eb664c", null ],
    [ "initialise", "classjuce_1_1AudioDeviceManager.html#ab19f2c59927f3abfe561c1f366c206a5", null ],
    [ "initialiseWithDefaultDevices", "classjuce_1_1AudioDeviceManager.html#ac3ccd841ec775ee05ae19f1310a2abfe", null ],
    [ "isMidiInputDeviceEnabled", "classjuce_1_1AudioDeviceManager.html#a05f7a258bad375339b3e8c9edd778553", null ],
    [ "isMidiInputEnabled", "classjuce_1_1AudioDeviceManager.html#a431199a6479e22152fb9f1ae0529d77b", null ],
    [ "playTestSound", "classjuce_1_1AudioDeviceManager.html#aeebc265574343aa6eaaf220048ec5893", null ],
    [ "removeAudioCallback", "classjuce_1_1AudioDeviceManager.html#ae1e7ecadfb4c2e5d3e3263b13d0b52ea", null ],
    [ "removeAudioDeviceType", "classjuce_1_1AudioDeviceManager.html#a1ee90d90317448adb6802209c8d885ba", null ],
    [ "removeMidiInputCallback", "classjuce_1_1AudioDeviceManager.html#a3e3fa9f903e4becb1db1d5669404e1d8", null ],
    [ "removeMidiInputDeviceCallback", "classjuce_1_1AudioDeviceManager.html#a2d96aaea232d73697ea0a1b9b20b1419", null ],
    [ "restartLastAudioDevice", "classjuce_1_1AudioDeviceManager.html#ac41c13ba9dd7f5ca5d9aaa27d2919277", null ],
    [ "setAudioDeviceSetup", "classjuce_1_1AudioDeviceManager.html#a3291995e9b283b2493e03cfdd9e42d5e", null ],
    [ "setCurrentAudioDeviceType", "classjuce_1_1AudioDeviceManager.html#aa305ce62ac86b63c32da20680d93031f", null ],
    [ "setDefaultMidiOutput", "classjuce_1_1AudioDeviceManager.html#a735edf0a881fc58673d1c4e09aea0aed", null ],
    [ "setDefaultMidiOutputDevice", "classjuce_1_1AudioDeviceManager.html#a679ed9ed74b54c430dd984cd884c47db", null ],
    [ "setMidiInputDeviceEnabled", "classjuce_1_1AudioDeviceManager.html#a727e1d875e90215aa50433efd73b47e6", null ],
    [ "setMidiInputEnabled", "classjuce_1_1AudioDeviceManager.html#a615a80abf7293fc9ff6b9e12b29cf6bb", null ]
];

==> libopenshot-audio-docs-0.4.0-1-aarch64.pkg.tar.xz: usr/share/doc/OpenShotAudio/API/classjuce_1_1AudioDeviceManager.js <==
var classjuce_1_1AudioDeviceManager =
[
    [ "AudioDeviceSetup", "structjuce_1_1AudioDeviceManager_1_1AudioDeviceSetup.html", "structjuce_1_1AudioDeviceManager_1_1AudioDeviceSetup" ],
    [ "LevelMeter", "structjuce_1_1AudioDeviceManager_1_1LevelMeter.html", null ],
    [ "AudioDeviceManager", "classjuce_1_1AudioDeviceManager.html#a0f94252c05cdcfb54bbe5268b8c899c1", null ],
    [ "~AudioDeviceManager", "classjuce_1_1AudioDeviceManager.html#aa75a7b8cdfe4140f2b5f2c29079ad597", null ],
    [ "addAudioCallback", "classjuce_1_1AudioDeviceManager.html#ab8142650e2dc99996da8e8680861ab2e", null ],
    [ "addAudioDeviceType", "classjuce_1_1AudioDeviceManager.html#af34a975de197da7f381c66b649ea80b7", null ],
    [ "addMidiInputDeviceCallback", "classjuce_1_1AudioDeviceManager.html#a99e95f950308e4819eaef5bb00950ebd", null ],
    [ "closeAudioDevice", "classjuce_1_1AudioDeviceManager.html#af953ec126738f7cb6a32a9b2dc1a3d71", null ],
    [ "createAudioDeviceTypes", "classjuce_1_1AudioDeviceManager.html#a4e7b2c8576293258d578aa9a047ad1b3", null ],
    [ "createStateXml", "classjuce_1_1AudioDeviceManager.html#afa4b3140e09746cddfa28b230aeb2687", null ],
    [ "getAudioCallbackLock", "classjuce_1_1AudioDeviceManager.html#ab2432e30713bfb4c70937e740fda3674", null ],
    [ "getAudioDeviceSetup", "classjuce_1_1AudioDeviceManager.html#a259eff30308a989151915257f0b36c19", null ],
    [ "getAudioDeviceSetup", "classjuce_1_1AudioDeviceManager.html#a8e38b3ad92023fc1ab397bd1ca92ff85", null ],
    [ "getAvailableDeviceTypes", "classjuce_1_1AudioDeviceManager.html#aa792795a2b934872135d7c4038bca414", null ],
    [ "getCpuUsage", "classjuce_1_1AudioDeviceManager.html#a2fc200595e625e07ce7ef0f8fe046c85", null ],
    [ "getCurrentAudioDevice", "classjuce_1_1AudioDeviceManager.html#a46c369de913882cca55a1c1f80a0a818", null ],
    [ "getCurrentAudioDeviceType", "classjuce_1_1AudioDeviceManager.html#a4dc6b28ff963bbacc26d8f7279ae2ac3", null ],
    [ "getCurrentDeviceTypeObject", "classjuce_1_1AudioDeviceManager.html#a30b3777cba7f46b18f89afb1089054a9", null ],
    [ "getDefaultMidiOutput", "classjuce_1_1AudioDeviceManager.html#a081e904378810fbf6a3c11bf9a7d0231", null ],
    [ "getDefaultMidiOutputIdentifier", "classjuce_1_1AudioDeviceManager.html#a2918c2cf418155c37bf9924820e700c9", null ],
    [ "getDeviceAudioWorkgroup", "classjuce_1_1AudioDeviceManager.html#af790e2c4659fc12bd1b4803ba14b717f", null ],
    [ "getInputLevelGetter", "classjuce_1_1AudioDeviceManager.html#a0e2b2e556d1d1b64fdf9ce5991eb2713", null ],
    [ "getMidiCallbackLock", "classjuce_1_1AudioDeviceManager.html#a0ee22305ac3a05454e335311f50d9ebf", null ],
    [ "getOutputLevelGetter", "classjuce_1_1AudioDeviceManager.html#a417f8b4d46c8ada26493734532399977", null ],
    [ "getXRunCount", "classjuce_1_1AudioDeviceManager.html#a7e4900c55e080cbbdf646e3e31eb664c", null ],
    [ "initialise", "classjuce_1_1AudioDeviceManager.html#ab19f2c59927f3abfe561c1f366c206a5", null ],
    [ "initialiseWithDefaultDevices", "classjuce_1_1AudioDeviceManager.html#ac3ccd841ec775ee05ae19f1310a2abfe", null ],
    [ "isMidiInputDeviceEnabled", "classjuce_1_1AudioDeviceManager.html#a05f7a258bad375339b3e8c9edd778553", null ],
    [ "playTestSound", "classjuce_1_1AudioDeviceManager.html#aeebc265574343aa6eaaf220048ec5893", null ],
    [ "removeAudioCallback", "classjuce_1_1AudioDeviceManager.html#ae1e7ecadfb4c2e5d3e3263b13d0b52ea", null ],
    [ "removeAudioDeviceType", "classjuce_1_1AudioDeviceManager.html#a1ee90d90317448adb6802209c8d885ba", null ],
    [ "removeMidiInputDeviceCallback", "classjuce_1_1AudioDeviceManager.html#a2d96aaea232d73697ea0a1b9b20b1419", null ],
    [ "restartLastAudioDevice", "classjuce_1_1AudioDeviceManager.html#ac41c13ba9dd7f5ca5d9aaa27d2919277", null ],
    [ "setAudioDeviceSetup", "classjuce_1_1AudioDeviceManager.html#a3291995e9b283b2493e03cfdd9e42d5e", null ],
    [ "setCurrentAudioDeviceType", "classjuce_1_1AudioDeviceManager.html#aa305ce62ac86b63c32da20680d93031f", null ],
    [ "setDefaultMidiOutputDevice", "classjuce_1_1AudioDeviceManager.html#a679ed9ed74b54c430dd984cd884c47db", null ],
    [ "setMidiInputDeviceEnabled", "classjuce_1_1AudioDeviceManager.html#a727e1d875e90215aa50433efd73b47e6", null ]
];
